aboutsummaryrefslogtreecommitdiff
path: root/discord/invite.py
diff options
context:
space:
mode:
authorRapptz <[email protected]>2016-10-17 18:25:23 -0400
committerRapptz <[email protected]>2017-01-03 09:51:54 -0500
commitd1d54a468a88323a8ef7798ff084a1371d5893ec (patch)
tree21dd315df95acd2c8d6cf63cc51fa4cadc0c7155 /discord/invite.py
parentStateful Message and remove Invite.xkcd since it is removed. (diff)
downloaddiscord.py-d1d54a468a88323a8ef7798ff084a1371d5893ec.tar.xz
discord.py-d1d54a468a88323a8ef7798ff084a1371d5893ec.zip
Rename Server to Guild everywhere.
Diffstat (limited to 'discord/invite.py')
-rw-r--r--discord/invite.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/discord/invite.py b/discord/invite.py
index 91136ac2..47fd494c 100644
--- a/discord/invite.py
+++ b/discord/invite.py
@@ -29,7 +29,7 @@ from .utils import parse_time
from .mixins import Hashable
class Invite(Hashable):
"""Represents a Discord :class:`Server` or :class:`Channel` invite.
Depending on the way this object was created, some of the attributes can
have a value of ``None``.
@@ -54,8 +54,8 @@ class Invite(Hashable):
How long the before the invite expires in seconds. A value of 0 indicates that it doesn't expire.
code: str
The URL fragment used for the invite. :attr:`xkcd` is also a possible fragment.
- server: :class:`Server`
- The server the invite is for.
+ guild: :class:`Guild`
+ The guild the invite is for.
revoked: bool
Indicates if the invite has been revoked.
created_at: `datetime.datetime`
@@ -74,14 +74,14 @@ class Invite(Hashable):
"""
- __slots__ = ( 'max_age', 'code', 'server', 'revoked', 'created_at', 'uses',
+ __slots__ = ( 'max_age', 'code', 'guild', 'revoked', 'created_at', 'uses',
'temporary', 'max_uses', 'inviter', 'channel', '_state' )
def __init__(self, *, state, data):
self._state = state
self.max_age = data.get('max_age')
self.code = data.get('code')
- self.server = data.get('server')
+ self.guild = data.get('guild')
self.revoked = data.get('revoked')
self.created_at = parse_time(data.get('created_at'))
self.temporary = data.get('temporary')
@@ -29,7 +29,7 @@ from .utils import parse_time
from .mixins import Hashable
class Invite(Hashable):
- """Represents a Discord :class:`Server` or :class:`Channel` invite.
+ """Represents a Discord :class:`Guild` or :class:`Channel` invite.
Depending on the way this object was created, some of the attributes can
have a value of ``None``.